@@ -10,15 +10,20 @@
 use super::{
   client_message_sorter::ClientMessageSorter,
   device::{ButtplugClientDevice, ButtplugClientDeviceEvent},
-  ButtplugClientEvent, ButtplugClientMessageFuturePair,
+  ButtplugClientEvent,
+  ButtplugClientMessageFuturePair,
 };
 use crate::{
   connector::{ButtplugConnector, ButtplugConnectorStateShared},
   core::{
     errors::{ButtplugDeviceError, ButtplugError},
     messages::{
-      ButtplugCurrentSpecClientMessage, ButtplugCurrentSpecServerMessage, ButtplugDeviceMessage,
-      ButtplugMessageValidator, DeviceList, DeviceMessageInfo,
+      ButtplugCurrentSpecClientMessage,
+      ButtplugCurrentSpecServerMessage,
+      ButtplugDeviceMessage,
+      ButtplugMessageValidator,
+      DeviceList,
+      DeviceMessageInfo,
     },
   },
 };
@@ -167,17 +172,22 @@ where
       return;
     }
 
-    // The only reason a send will fail is if we have no receivers. Since we
-    // already checked for receivers here, we can unwrap without issue.
-    self.to_client_sender.send(event).unwrap();
+    self
+      .to_client_sender
+      .send(event)
+      .expect("Already checked for receivers.");
   }
 
   fn disconnect_device(&mut self, device_index: u32) {
     if !self.device_map.contains_key(&device_index) {
       return;
     }
-    // Checked for device index existence, can unwrap here.
-    let device = (*self.device_map.get(&device_index).unwrap()).clone();
+
+    let device = (*self
+      .device_map
+      .get(&device_index)
+      .expect("Checked for device index already."))
+    .clone();
     device.set_device_connected(false);
     device.queue_event(ButtplugClientDeviceEvent::DeviceRemoved);
     // Then remove it from our storage map
@@ -263,8 +273,9 @@ where
 
     trace!("Sending message to connector: {:?}", msg_fut.msg);
     self.sorter.register_future(&mut msg_fut);
-    // TODO What happens if the connector isn't connected?
-    self.connector.send(msg_fut.msg).await.unwrap();
+    if self.connector.send(msg_fut.msg).await.is_err() {
+      error!("Sending message failed, connector most likely no longer connected.");
+    }
   }
 
   /// Parses message types from the client, returning false when disconnect
