@@ -6,7 +6,13 @@ use btleplug::{
 };
 use futures::{future::FutureExt, StreamExt};
 use futures_timer::Delay;
-use std::time::Duration;
+use std::{
+  sync::{
+    atomic::{AtomicBool, Ordering},
+    Arc,
+  },
+  time::Duration,
+};
 use tokio::sync::mpsc::{Receiver, Sender};
 
 #[derive(Debug, Clone, Copy)]
@@ -25,16 +31,19 @@ struct PeripheralInfo {
 pub struct BtleplugAdapterTask {
   event_sender: Sender<DeviceCommunicationEvent>,
   command_receiver: Receiver<BtleplugAdapterCommand>,
+  adapter_connected: Arc<AtomicBool>,
 }
 
 impl BtleplugAdapterTask {
   pub fn new(
     event_sender: Sender<DeviceCommunicationEvent>,
     command_receiver: Receiver<BtleplugAdapterCommand>,
+    adapter_connected: Arc<AtomicBool>,
   ) -> Self {
     Self {
       event_sender,
       command_receiver,
+      adapter_connected,
     }
   }
 
@@ -127,11 +136,12 @@ impl BtleplugAdapterTask {
 
     // Start by assuming we'll find the adapter on the first try. If not, we'll print an error
     // message then loop while trying to find it.
-    let mut adapter_found = true;
+    self.adapter_connected.store(true, Ordering::SeqCst);
 
     let adapter;
 
     loop {
+      let adapter_found = self.adapter_connected.load(Ordering::SeqCst);
       if !adapter_found {
         Delay::new(Duration::from_secs(1)).await;
       }
@@ -175,7 +185,7 @@ impl BtleplugAdapterTask {
             adapter
           } else {
             if adapter_found {
-              adapter_found = false;
+              self.adapter_connected.store(false, Ordering::SeqCst);
               warn!("Bluetooth LE adapter not found, will not be using bluetooth scanning until found. Buttplug will continue polling for the adapter, but no more warning messages will be posted.");
             }
             continue;
@@ -183,7 +193,7 @@ impl BtleplugAdapterTask {
         }
         Err(e) => {
           if adapter_found {
-            adapter_found = false;
+            self.adapter_connected.store(false, Ordering::SeqCst);
             error!("Error retreiving BTLE adapters: {:?}", e);
           }
           continue;
